@@ -52,7 +52,7 @@
 #' @return An object of class MSE
 #' @author A. Hordyk and T. Carruthers
 #' @export runMSErobust
-runMSErobust <- function(OM = testOM, MPs = c("AvC", "DCAC", "FMSYref", "curE", "matlenlim"), 
+runMSErobust <- function(OM = DLMtool::testOM, MPs = c("AvC", "DCAC", "FMSYref", "curE", "matlenlim"), 
                          nsim = 256, proyears = 50, interval = 4, pstar = 0.5, 
                          maxF = 0.8, timelimit = 1, reps = 1, CheckMPs = FALSE, Hist = FALSE, 
                          ntrials = 50, fracD = 0.05, CalcBlow = FALSE, HZN = 2, Bfrac = 0.5,
@@ -105,30 +105,31 @@ runMSErobust <- function(OM = testOM, MPs = c("AvC", "DCAC", "FMSYref", "curE",
     error <- 1
     crash <- 0
 	  st <- Sys.time()
-    while (error == 1 & crash <= maxCrash) { 
+    while (error == 1 & crash <= maxCrash) {
+      assign("last.warning", NULL, envir = baseenv())
       tryOM <- OM
       tryOM@seed <- OM@seed + i + crash  # change seed 
       tryOM@nsim <- length(simsplit[[i]]) # sub number of sims 
       if (length(cpars) > 0) { # subset cpars
         Subcpars <- cpars
+        if (ncparsim < nsim) ind <- sample(1:ncparsim, length(index), replace=TRUE)
+        if (!ncparsim < nsim) ind <- sample(index, length(index), replace=FALSE)
         for (jj in 1:length(cpars)) {
           index <- as.numeric(unlist(simsplit[i]))
-          if (ncparsim < nsim) ind <- sample(1:ncparsim, length(index), replace=TRUE)
-          if (!ncparsim < nsim) ind <- sample(index, length(index), replace=FALSE)
           its <- cpars[[jj]]
-          name <- names(cpars)[jj]
+          cname <- names(cpars)[jj]
           if (any(c("EffUpper", "EffLower", "EffYears", "maxage") %in% name)) {
             # do nothing
           } else {
             if (class(its) == "numeric" | class(its) == "integer") {
-              Subcpars[[name]] <- its[ind]
+              Subcpars[[cname]] <- its[ind]
             }
             if (class(its) == "matrix") {
-              Subcpars[[name]] <-  its[ind,, drop=FALSE]
+              Subcpars[[cname]] <-  its[ind,, drop=FALSE]
             }
             if (class(its) == "array") {
               if (length(dim(its)) == 3) {
-                Subcpars[[name]] <- its[ind, , ,drop=FALSE]
+                Subcpars[[cname]] <- its[ind, , ,drop=FALSE]
               }
             }
           }	
